@@ -229,7 +229,7 @@ apply_config (struct DisplayInfo *info)
 					      gdk_x11_drawable_get_xid (GDK_DRAWABLE (root_window)),
 					      new_res,
 					      new_rot,
-					      new_rate,
+					      new_rate > 0 ? new_rate : 0,
 					      GDK_CURRENT_TIME);
 	}
     }
@@ -277,7 +277,7 @@ revert_config (struct DisplayInfo *info)
 					  gdk_x11_drawable_get_xid (GDK_DRAWABLE (root_window)),
 					  screen_info->old_size,
 					  screen_info->old_rotation,
-					  screen_info->old_rate,
+					  screen_info->old_rate > 0 ? screen_info->old_rate : 0,
 					  GDK_CURRENT_TIME);
       
     }
@@ -664,7 +664,6 @@ create_dialog (struct DisplayInfo *info)
       client = gconf_client_get_default ();
       key = g_strconcat ("/desktop/gnome/screen/", hostname,  "/0/resolution",NULL);
       resolution = gconf_client_get_string (client, key, NULL);
-      g_free (resolution);
       g_free (key);
       g_object_unref (client);
       
@@ -678,6 +677,8 @@ create_dialog (struct DisplayInfo *info)
       gtk_box_pack_start (GTK_BOX (vbox),
 			  wrapped, FALSE, FALSE, 0);
       gtk_widget_show (wrapped);
+
+      g_free (resolution);
     }
 
   info->per_computer_check = per_computer_check;
